rgrit-proc 0.1.0

Proc macros for the rgrit crate
docs.rs failed to build rgrit-proc-0.1.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: rgrit-proc-0.1.1

rgrit-proc

This crate contains the proc macros for the rgrit crate. For more information, see the main crate.